@@ -1,6 +1,10 @@
 # Standard lib
+from pathlib import Path
 import threading
 
+# Third party
+import appdirs
+
 # Local
 from .conf import Settings
 
@@ -9,5 +13,6 @@ inactive_flag = threading.Event()
 
 # Project settings
 settings = Settings(
-    appname="WillSpeak"
+    appname="WillSpeak",
+    appdata_path=Path(appdirs.user_data_dir("WillSpeak"))
 )
