@@ -1,8 +1,13 @@
+# Standard lib
+from pathlib import Path
+
+# Third party
 from pydantic import BaseModel
 
 
 class Settings(BaseModel):
     appname: str
+    appdata_path: Path
     timeout: float = 0.1
     port: int = 9999
     volume: int = 100
