@@ -5,11 +5,12 @@ text to a processing queue.
 
 # Standard lib
 from multiprocessing.connection import Listener, Client
-from threading import Thread
+from threading import Thread, Event
 from typing import Callable
 import queue
 
 # Third party
+from pyclip.base import ClipboardException
 import pyclip
 
 # Local
@@ -18,9 +19,35 @@ from willspeak import inactive_flag, settings, filters
 
 class ClipboardMonitor(Thread):
     """Monitors the clipboard for changes and adds to processing queue."""
+
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self._process_queue = queue.Queue()
+        self._paused = Event()
+        filters.prepare()
+
+    def pause(self):
+        """
+        Pause monitoring of the clipboard.
+        """
+        self._paused.set()
+        print("Clipboard monitoring disabled")
+
+    def unpause(self):
+        """
+        Unpause clipboard monitoring.
+        """
+        self._paused.clear()
+        print("Clipboard monitoring enabled")
+
+    def toggle(self):
+        """
+        Toggle clipboard monitoring between paused and un paused.
+        """
+        if self._paused.is_set():
+            self.unpause()
+        else:
+            self.pause()
 
     # noinspection PyUnusedLocal
     def run(self) -> None:
@@ -36,12 +63,17 @@ class ClipboardMonitor(Thread):
             # Ensure that we don't have the same text again
             if text and text != prev_text:
                 prev_text = text
-                self._process_queue.put(text)
+                if not self._paused.is_set():
+                    for processed_text in filters.process_text(text):
+                        self._process_queue.put(processed_text)
 
     # noinspection PyMethodMayBeStatic
     def get_clipboard(self) -> str:
         """Return text from clipboard."""
-        return pyclip.paste(text=True).strip()
+        try:
+            return pyclip.paste(text=True).strip()
+        except ClipboardException:
+            return ""
 
     def wait_for_text(self, callback: Callable[[str], None]):
         """
@@ -59,9 +91,9 @@ class ClipboardMonitor(Thread):
                 continue
 
             try:
-                # Process text before speaking
-                for text in filters.process_text(text):
-                    callback(text)
+                callback(text)
+            except Exception as e:
+                print(f"Error: Speak failed - {e}")
             finally:
                 self._process_queue.task_done()
 
@@ -87,16 +119,18 @@ class ProcessMonitor(Thread):
         listener.close()
 
     def start_server(self, **commands):
-        """Start the process listener server to check for process comamnds."""
+        """Start the process listener server to check for process commands."""
         self._commands = commands
         self.start()
 
-    def send_stop(self):
+    @classmethod
+    def send_simple_cmd(cls, command: str):
         """Send the stop signal to master process."""
         try:
-            conn = Client(("127.0.0.1", self.LISTEN_PORT))
+            conn = Client(("127.0.0.1", cls.LISTEN_PORT))
         except ConnectionRefusedError:
-            pass
+            return 1
         else:
-            conn.send("stop")
+            conn.send(command)
             conn.close()
+            return 0
